# Resources

```{note}
This page is under development.
```

## Links to FLOPS docs

[Here](https://software.nasa.gov/software/LAR-18934-1) is where you can read more about FLOPS.

## Links to GASP docs

[This is the first publication about GASP](https://ntrs.nasa.gov/api/citations/19810010562/downloads/19810010562.pdf) and there are multiple follow-on publications.
The GASP code is not publicly available, but the publications are a good resource for understanding the theory behind GASP.

## Publications List

As we develop and use the Aviary code we will add publications here.
